    <?php
/**
 * Plugin Name: Securating
 * Plugin URI: http://cdn.securating.com/securating
 * Description: Avec Securating affiché sur votre site, vous sécurisez vos visiteurs en leur proposant de consulter des avis client librement déposés.
 * Version: 1.1
 * Author: Gilbert Schaffer
 * Author URI: http://www.securating.com
 */

function add_securating_footer_content() {

    wp_enqueue_script( 'Securating-build-js', 'https://api.securating.io/resource/build.js', array(), '1.0', true ) ;

    $content = '<div id="securating"></div>';
    $content .= '<iframe id="sr_iframe_localstorage" src="https://api.securating.io" style="display:none;"></iframe>';

    $securating_theme = get_option( 'securating_theme' , null );
    if($securating_theme) $content .= '<meta property="securating:theme" content="'.$securating_theme.'">';

    $securating_accent = get_option( 'securating_accent' , null );
    if($securating_accent) $content .= '<meta property="securating:accent" content="'.$securating_accent.'">';

    $securating_locale = get_option( 'securating_locale' , null );
    if($securating_locale) $content .= '<meta property="securating:locale" content="'.$securating_locale.'">';

    $securating_menux = get_option( 'securating_menux' , null );
    if($securating_menux) $content .= '<meta property="securating:menu-x" content="'.$securating_menux.'">';

    $securating_menuy = get_option( 'securating_menuy' , null );
    if($securating_menuy) $content .= '<meta property="securating:menu-y" content="'.$securating_menuy.'">';

    echo $content;

}
add_action( 'wp_footer', 'add_securating_footer_content' );

/**
 * shortcode_securating_widget()
 * 
 * This function includes the Securatng Widget Rating
 */
function shortcode_securating_widget($atts = [], $content = null, $tag = '' ){
    $securating_token = get_securating_token();
    if(!securating_ckeck_token($securating_token)) return '';

    $widgetUrl = 'https://api.securating.io/widgets/v1';
    $widgetUrl .= '?token='.$securating_token;

    $widget_v1_attributes = [
            'type','include','from','exclude','order','internal_ref','ids','limit','title','logo_direction','logo_size',
            'hide_overview', 'hide_reviews', 'hide_schema', 'hide_style',
            'hide_title', 'hide_rating', 'hide_no_rating', 'hide_distribution', 'hide_total', 'hide_name',
            'hide_logo', 'hide_more_link', 'show_stars_total', 'show_stars_rating', 'hide_avatars'
    ];
    foreach($widget_v1_attributes as $attributeName) {
        if (isset($atts[$attributeName])) {
            if(empty($atts[$attributeName])) {
                $atts[$attributeName] = 'y' ;
            }
            $widgetUrl .= '&'.$attributeName.'='.$atts[$attributeName];
        }
    }
    return file_get_contents( $widgetUrl );
}
add_shortcode('securating_widget', 'shortcode_securating_widget');



/**
 * securating_setup_menu()
 * 
 * add the Securating Administration menu
 */
function securating_setup_menu(){
        add_menu_page( 'Securating Plugin Page', 'Securating', 'manage_options', 'test-plugin', 'securating_admin_main' );
}
add_action('admin_menu', 'securating_setup_menu');

/**
 * getLabels()
 * 
 * setup the labels regarding to the language
 */
function getLabels($lg){
    $securatingLabels=array();
    $securatingLabels['fr']['title']='Configuration du plugin Securating!';
    $securatingLabels['fr']['help']='Afin de pouvoir modérer les avis coillecté sur votre site, vous devez vérfier votre site depuis l\'espace client manager.securating.com ';
    
    $securatingLabels['fr']['update_ok']='Votre demande a bien été prise en compte';
    $securatingLabels['fr']['update_nok']='Attention, votre demande n\'a pas pu être prise en compte';

    $securatingLabels['fr']['missing_token']='Attention, vous devez renseigner un clé';
    $securatingLabels['fr']['invalid_token']='Attention, vous devez renseigner une clé valide';

    $securatingLabels['fr']['label_send']='Enregistrer les modifications';
    $securatingLabels['fr']['label_token']='Clé de vérification';
    $securatingLabels['fr']['help_token']='Cette clé est disponible depuis votre espace client sur Securating';
    $securatingLabels['fr']['help_link']='https://manager.securating.com';

    $securatingLabels['fr']['label_params']='Valeurs par défault pour Securating';
    $securatingLabels['fr']['label_theme']='Design';
    $securatingLabels['fr']['label_accent']='Ambiance';
    $securatingLabels['fr']['label_locale']='Langue';
    $securatingLabels['fr']['label_menuxy']='Positions X et Y en %';
    
    $securatingLabels['fr']['help_theme']='Le design et l\'ambiance sont appliqués pour tout nouveau visiteur.';
    
    $securatingLabels['fr']['help_widget']='Le widgets de Securating est intégrable avec le shortcode suivant: [securating_widget].';
    

    if(!isset($securatingLabels[$lg])) {
        $lg = 'fr' ;
    }
    return($securatingLabels[$lg]);
}
/**
 * securating_admin_main()
 * 
 * Main securating administration menu
 */
function securating_admin_main(){
    $lg = 'fr' ;
    $labels=getLabels($lg);
    if(isset($_POST['securating_admin_submit'])) 
    {
        $securating_token = sanitize_text_field($_POST['securating_token']) ;
        if( securating_ckeck_token($securating_token))
        {
            $securating_theme = sanitize_text_field($_POST['securating_theme']);
            $securating_accent = sanitize_text_field($_POST['securating_accent']);
            $securating_locale = sanitize_text_field($_POST['securating_locale']);
            $securating_menux = sanitize_text_field($_POST['securating_menux']);
            $securating_menuy = sanitize_text_field($_POST['securating_menuy']);
            //-- Fill the setup option to save
            $data = [
                'securating_theme' => $securating_theme,
                'securating_accent' => $securating_accent,
                'securating_locale' => $securating_locale,
                'securating_menux' => $securating_menux,
                'securating_menuy' => $securating_menuy,
            ] ;
            if(securating_admin_save($securating_token, $data)) {
                echo '<p style="color:green;">'.esc_html($labels['update_ok']).'</p>';
            } else {
                echo '<p style="color:red;">'.esc_html($labels['update_nok']).'</p>';
            } 
        } else {
            if(empty($_POST['securating_token'])) {                
                echo '<p style="color:red;">'.esc_html($labels['missing_token']).'</p>';
            } else {
                echo '<p style="color:red;">'.esc_html($labels['invalid_token']).'</p>';
            }
            echo '<p style="color:red;">'.esc_html($securating_token).'</p>';
        }
    } else {
        //--
        $securating_theme = get_option( 'securating_theme' , '' );
        $securating_accent = get_option( 'securating_accent' , '' );
        $securating_locale = get_option( 'securating_locale' , '' );
        $securating_menux = get_option( 'securating_menux' , '' );
        $securating_menuy = get_option( 'securating_menuy' , '' );
    }
    
    $securating_token = get_securating_token();
   
    echo '<h1>'. esc_html($labels['title']) .'</h1>';
    echo '<form method="POST">';
    echo '<table class="form-table">';
    echo '<tbody>';

    echo '<tr>';
    echo '<th scope="row">';
    echo '<label for="token">'. esc_html($labels['label_token']) .'</label>';
    echo '</th>';
    echo '<td>';
    echo '<input name="securating_token" type="text" id="securating_token" value="'. esc_attr($securating_token) .'" class="regular-text">';
    echo '<br>';
    echo '<i>'. esc_html($labels['help_token']) .'</i> : <a href="'. $labels['help_link'] .'">'. $labels['help_link'] .'</a>';
    echo '</td>';
    echo '</tr>';

    echo '<tr>';
    echo '<td colspan=2>';
    echo '<h3>'. esc_html($labels['label_params']) .'</h3>';
    echo '</td>';
    echo '</tr>';

    echo '<tr>';
    echo '<th scope="row">';
    echo '<label for="securating_theme">'. esc_html($labels['label_theme']) .'</label>';
    echo '</th>';
    echo '<td>';
    echo '<select name="securating_theme" type="text" id="securating_theme">';
    $themes = [
        'base' => "Base",
        'light' => 'Light',
        'vicking' => 'Vicking',
    ];
    foreach( $themes as $k => $v) {
        $selected = '' ; if($securating_theme==$k) $selected = 'SELECTED' ;
        echo '<option '. $selected .' value="'. $k .'">'. $v .'</option>';    
    }
    echo '</select>';
    echo '<br>';
    echo '<i>'. esc_html($labels['help_theme']) .'</i>';
    echo '</td>';
    echo '</tr>';

        
    echo '<tr>';
    echo '<th scope="row">';
    echo '<label for="securating_accent">'. esc_html($labels['label_accent']) .'</label>';
    echo '</th>';
    echo '<td>';
    echo '<select name="securating_accent" type="text" id="securating_accent">';
    $accents = [
        'white' => "Blanc",
        'pastel' => 'Pastel',
        'whale' => 'Baleine',
        'dark' => 'Sombre',
    ];
    foreach( $accents as $k => $v ) {
        $selected = '' ; if($securating_accent==$k) $selected = 'SELECTED' ;
        echo '<option '. $selected .' value="'. $k .'">'. $v .'</option>';    
    }
    echo '</select>';
    echo '<br>';
    echo '<i>'. esc_html($labels['help_accent']) .'</i>';
    echo '</td>';
    echo '</tr>';
    
    
    echo '<tr>';
    echo '<th scope="row">';
    echo '<label for="securating_locale">'. esc_html($labels['label_locale']) .'</label>';
    echo '</th>';
    echo '<td>';
    echo '<select name="securating_locale" type="text" id="securating_locale">';
    $locales = [
        'fr' => "Français",
        'en' => 'Anglais',
    ];
    foreach( $locales as $k => $v) {
        $selected = '' ; if($securating_locale==$k) $selected = 'SELECTED' ;
        echo '<option '. $selected .' value="'. $k .'">'. $v .'</option>';    
    }
    echo '</select>';
    echo '<br>';
    echo '<i>'. esc_html($labels['help_locale']) .'</i>';
    echo '</td>';
    echo '</tr>';
    

    echo '<tr>';
    echo '<th scope="row">';
    echo '<label for="securating_menux">'. esc_html($labels['label_menuxy']) .'</label>';
    echo '</th>';
    echo '<td>';
    echo 'X: <input name="securating_menux" type="text" id="securating_menux" value="'. esc_attr($securating_menux) .'" class="regular-text" style="width:50px;"> % , ';
    echo 'Y: <input name="securating_menuy" type="text" id="securating_menuy" value="'. esc_attr($securating_menuy) .'" class="regular-text" style="width:50px;"> % ';
    echo '<br>';
    echo '<i>'. esc_html($labels['help_locale']) .'</i>';
    echo '</td>';
    echo '</tr>';


    echo '</tbody>';
    echo '</table>';
    echo '<p class="submit">';
    echo '<input type="submit" name="securating_admin_submit" value="'. esc_attr($labels['label_send']) .'" class="button button-primary"/>';
    echo '</p>';
    echo '</form>';

}
/**
 * get_securating_token()
 * 
 * This function return the current Securating Token if exist
 */
function get_securating_token(){
    $token = '' ;
    foreach (glob(securating_wp_config_path() . '/securating_*.txt') as $tokenFilename) {
        $token = file_get_contents($tokenFilename) ;
        break;
    }
    return $token;
}
/**
 * securating_wp_config_path()
 * 
 * Get the homedir path 
 */
function securating_wp_config_path(){
    $base = dirname(__FILE__);
    $path = false;

    if (@file_exists(dirname(dirname($base))."/wp-config.php"))
    {
        $path = dirname(dirname($base));
    }
    else
        if (@file_exists(dirname(dirname(dirname($base)))."/wp-config.php"))
        {
            $path = dirname(dirname(dirname($base)));
        }
        else
            $path = false;

    if ($path != false)
    {
        $path = str_replace("\\", "/", $path);
    }
    return $path;
}

/**
 * securating_admin_save()
 * 
 * save the token to a local file
 */
function securating_admin_save($securating_token, $data = null){
    $saveDone = false ;
    $tokenFilename = securating_wp_config_path() . '/'.sanitize_file_name('securating_'.substr($securating_token,0,6).'.txt');
    
    //-- remove all existing securating token files
    @array_map('unlink', glob(securating_wp_config_path() . '/securating_*.txt'));
    //-- create the wanted securating token file
    if(file_put_contents($tokenFilename, $securating_token)===false) {
        $saveDone=false;
    } else {            
        foreach($data as $k => $v) {
            if(!add_option($k, $v)) {
                update_option($k, $v);
            }
        }
        $saveDone=true;
    }
    return($saveDone);
}
/**
 * securating_ckeck_token()
 * 
 * return true if we get a jwt valid token
 */
function securating_ckeck_token($securating_token){
    return strlen($securating_token)==64;
}
